==> 1.7.2.zip: harbour-sailotp/translations/harbour-sailotp-es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>About</name>
    <message>
        <location filename="../qml/pages/About.qml" line="75"/>
        <source>A Simple Sailfish OTP Generator
(RFC 6238/4226 compatible)</source>
        <translation>Un sencillo generador de códigos OTP
(Compatible con RFC 6238/4226)</translation>
    </message>
    <message>
        <location filename="../qml/pages/About.qml" line="84"/>
        <source>Copyright: Stefan Brand
License: BSD (3-clause)</source>
        <translation>Derechos de autor: Stefan Brand
Licencia: BSD (de 3 cláusulas)</translation>
    </message>
    <message>
        <location filename="../qml/pages/About.qml" line="110"/>
        <source>SailOTP uses the following third party libs:</source>
        <translation>SailOTP usa las siguientes librerías de terceros:</translation>
    </message>
    <message>
        <location filename="../qml/pages/About.qml" line="121"/>
        <source>Contributors:</source>
        <translation>Contribuidor:</translation>
    </message>
    <message>
        <location filename="../qml/pages/About.qml" line="121"/>
        <source>Support</source>
        <translation>soporte</translation>
    </message>
    <message>
        <location filename="../qml/pages/About.qml" line="132"/>
        <source>Translators:</source>
        <translation>Traductores:</translation>
    </message>
</context>
<context>
    <name>AddOTP</name>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="69"/>
        <source>Show QR-Code</source>
        <translation>Mostrar código QR</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="72"/>
        <source>Can&apos;t create QR-Code from incomplete settings!</source>
        <translation>¡No se puede crear el código QR a partir de una configuración incompleta!</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="86"/>
        <source>Save</source>
        <translation>Guardar</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="86"/>
        <source>Add</source>
        <translation>Añadir</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="91"/>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="93"/>
        <source>Time-based (TOTP)</source>
        <translation>Basado en tiempo (TOTP)</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="94"/>
        <source>Counter-based (HOTP)</source>
        <translation>Basado en contador (HOTP)</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="95"/>
        <source>Steam Guard</source>
        <translation>Steam Guard</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="101"/>
        <source>Title</source>
        <translation>Título</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="102"/>
        <source>Title for the OTP</source>
        <translation>Nombre para el OTP</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="114"/>
        <source>Secret (at least 16 characters)</source>
        <translation>Cadena secreta (al menos 16 caracteres)</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="116"/>
        <source>Secret OTP Key</source>
        <translation>Llave secreta OTP</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="128"/>
        <source>Length</source>
        <translation>Longitud</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="130"/>
        <source>Length of the Token</source>
        <translation>Longitud del token</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="142"/>
        <location filename="../qml/pages/AddOTP.qml" line="144"/>
        <source>Time Derivation (Seconds)</source>
        <translation>Derivación de tiempo (segundos)</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="156"/>
        <source>Next Counter Value</source>
        <translation>Siguiente Contador</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="158"/>
        <source>Next Value of the Counter</source>
        <translation>Siguiente valor del contador</translation>
    </message>
</context>
<context>
    <name>ExportPage</name>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="63"/>
        <source>File already exists, choose &quot;Overwrite existing&quot; to overwrite it.</source>
        <translation>El fichero ya existe, escoja la opción &quot;Sobreescribir existente&quot; para sobreescribirlo.</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="72"/>
        <source>Given file does not exist!</source>
        <translation>¡El fichero proporcionado no exsiste!</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="91"/>
        <location filename="../qml/pages/ExportPage.qml" line="107"/>
        <source>Export</source>
        <translation>Exportar</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="91"/>
        <location filename="../qml/pages/ExportPage.qml" line="107"/>
        <source>Import</source>
        <translation>Importar</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="114"/>
        <source>Filename</source>
        <translation>Nombre del fichero</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="115"/>
        <source>File to import</source>
        <translation>Fichero a importar</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="115"/>
        <source>File to export</source>
        <translation>Fichero a exportar</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="128"/>
        <source>Overwrite existing</source>
        <translation>Sobreescribir existente</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="134"/>
        <source>Password</source>
        <translation>Contraseña</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="135"/>
        <source>Password for the file</source>
        <translation>Contraseña para el fichero</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="148"/>
        <source>Passwords don&apos;t match!</source>
        <translation>¡Las contraseñas no coinciden!</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="148"/>
        <source>Passwords match!</source>
        <translation>¡Las contraseñas coinciden!</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="149"/>
        <source>Repeated Password for the file</source>
        <translation>Contraseña repetida para el archivo</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="173"/>
        <source>Here you can Import Tokens from a file. Put in the file location and the password you used on export. Pull left to start the import.</source>
        <translation>Aquí puede Importar Tokens desde un fichero. Ponga la localización del fichero y la contraseña utilizada en la exportación. Tire hacia la izquierda para comenzar la importación.</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="189"/>
        <source>Here you can export Tokens to a file. The exported file will be encrypted with AES-256-CBC and Base64 encoded. Choose a strong password, the file will contain the secrets used to generate the Tokens for your accounts. Pull left to start the export.</source>
        <translation>Aquí puede exportar Tokens a un fichero. El fichero exportado será encriptado con AES-256-CBC y codificado en Base64. Escoja una contraseña segura, el fichero contendrá las cadenas secretas utilizadas para la generación de los Tokens. Tire hacia la izquierda para comenzar la exportación.</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="189"/>
        <source>To view the content of the export file outside of SailOTP use the following openssl command:</source>
        <translation>Para ver los contenidos del fichero de exportación fuera de SailOTP utilize el siguiente comando openssl:</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="211"/>
        <source>Error writing to file </source>
        <translation>Error escribiendo el fichero</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="213"/>
        <source>Token Database exported to </source>
        <translation>Base de datos de Tokens exportada en</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="216"/>
        <source>Could not encrypt tokens. Error: </source>
        <translation>No se ha podido encriptar los tokens. Error: </translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="219"/>
        <source>Could not read tokens from Database</source>
        <translation>No se ha podido leer los tokens desde la Base de datos</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="230"/>
        <source>Tokens imported from </source>
        <translation>Tokens importados desde</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="235"/>
        <source>Unable to decrypt file, did you use the right password?</source>
        <translation>No se ha podido desencriptar el fichero, ¿ha utilizado el password correcto?</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="238"/>
        <source>Could not read from file </source>
        <translation>No se ha podido leer desde el fichero</translation>
    </message>
</context>
<context>
    <name>MainView</name>
    <message>
        <location filename="../qml/pages/MainView.qml" line="96"/>
        <source>About</source>
        <translation>Acerca de</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="100"/>
        <source>Settings</source>
        <translation>Configuración</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="105"/>
        <source>Export / Import</source>
        <translation>Exportar/Importar</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="109"/>
        <source>Add Token</source>
        <translation>Añadir Token</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="139"/>
        <source>Nothing here</source>
        <translation>Nada aquí</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="140"/>
        <source>Pull down to add a OTP</source>
        <translation>Tire hacia abajo para añadir tokens OTP</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="151"/>
        <source>Deleting</source>
        <translation>Borrando</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="167"/>
        <source>Token for </source>
        <translation>Token para </translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="167"/>
        <source> copied to clipboard</source>
        <translation> copiado al portapapeles</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="235"/>
        <source>Move up</source>
        <translation>Ascender</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="240"/>
        <source>Move down</source>
        <translation>Descender</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="245"/>
        <source>Edit</source>
        <translation>Editar</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="251"/>
        <source>Delete</source>
        <translation>Borrar</translation>
    </message>
</context>
<context>
    <name>QRPage</name>
    <message>
        <location filename="../qml/pages/QRPage.qml" line="74"/>
        <source>Can&apos;t create QR-Code from incomplete settings!</source>
        <translation>¡No se puede crear el código QR a partir de una configuración incompleta!</translation>
    </message>
</context>
<context>
    <name>ScanOTP</name>
    <message>
        <location filename="../qml/pages/ScanOTP.qml" line="54"/>
        <source>Can&apos;t access temporary directory</source>
        <translation>No se puede acceder al directorio temporal</translation>
    </message>
    <message>
        <location filename="../qml/pages/ScanOTP.qml" line="64"/>
        <source>Add manually</source>
        <translation>Añadir manualmente</translation>
    </message>
    <message>
        <location filename="../qml/pages/ScanOTP.qml" line="71"/>
        <source>Scan Code</source>
        <translation>Escanear código</translation>
    </message>
    <message>
        <location filename="../qml/pages/ScanOTP.qml" line="71"/>
        <source>Scanning...</source>
        <translation>Escaneando...</translation>
    </message>
    <message>
        <location filename="../qml/pages/ScanOTP.qml" line="101"/>
        <source>No valid Token data found.</source>
        <translation>No se han encontrado datos válidos</translation>
    </message>
    <message>
        <location filename="../qml/pages/ScanOTP.qml" line="142"/>
        <source>Tap the picture to start / stop scanning. Pull down to add Token manually.</source>
        <translation>Toque la imagen para comenzar/parar el escaneo. Tire hacia abajo para una configuración manual.</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <location filename="../qml/pages/Settings.qml" line="50"/>
        <source>Settings</source>
        <translation>Configuración</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="52"/>
        <source>Behaviour</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="56"/>
        <source>Show Token as QRCode on Tap</source>
        <translation>Mostrar el token como código QR al tocar</translation>
    </message>
</context>
</TS>

==> 1.9.2.zip: harbour-sailotp/translations/harbour-sailotp-es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>About</name>
    <message>
        <location filename="../qml/pages/About.qml" line="70"/>
        <source>A simple Sailfish OTP generator</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/About.qml" line="78"/>
        <source>(RFC 6238/4226 compatible)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/About.qml" line="87"/>
        <source>Online Manual</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/About.qml" line="94"/>
        <source>Source Code &amp; Issue Tracker</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/About.qml" line="111"/>
        <source>Copyright</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/About.qml" line="120"/>
        <source>License</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/About.qml" line="120"/>
        <source>BSD (3-clause)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/About.qml" line="139"/>
        <source>SteamGuard support</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/About.qml" line="146"/>
        <source>Search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/About.qml" line="240"/>
        <source>SailOTP uses the following third party libs:</source>
        <translation>SailOTP usa las siguientes librerías de terceros:</translation>
    </message>
    <message>
        <location filename="../qml/pages/About.qml" line="133"/>
        <source>Contributors:</source>
        <translation>Contribuidor:</translation>
    </message>
    <message>
        <location filename="../qml/pages/About.qml" line="162"/>
        <source>Translators:</source>
        <translation>Traductores:</translation>
    </message>
</context>
<context>
    <name>AddOTP</name>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="69"/>
        <source>Show QR-Code</source>
        <translation>Mostrar código QR</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="72"/>
        <location filename="../qml/pages/AddOTP.qml" line="85"/>
        <source>Can&apos;t create QR-Code from incomplete settings!</source>
        <translation>¡No se puede crear el código QR a partir de una configuración incompleta!</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="98"/>
        <source>Add</source>
        <translation>Añadir</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="98"/>
        <source>Save</source>
        <translation>Guardar</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="103"/>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="105"/>
        <source>Time-based (TOTP)</source>
        <translation>Basado en tiempo (TOTP)</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="106"/>
        <source>Counter-based (HOTP)</source>
        <translation>Basado en contador (HOTP)</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="107"/>
        <source>Steam Guard</source>
        <translation>Steam Guard</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="113"/>
        <source>Title</source>
        <translation>Título</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="114"/>
        <source>Title for the OTP</source>
        <translation>Nombre para el OTP</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="126"/>
        <source>Secret (at least 16 characters)</source>
        <translation>Cadena secreta (al menos 16 caracteres)</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="128"/>
        <source>Secret OTP Key</source>
        <translation>Llave secreta OTP</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="142"/>
        <source>Length</source>
        <translation>Longitud</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="144"/>
        <source>Length of the Token</source>
        <translation>Longitud del token</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="156"/>
        <location filename="../qml/pages/AddOTP.qml" line="158"/>
        <source>Time Derivation (Seconds)</source>
        <translation>Derivación de tiempo (segundos)</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="170"/>
        <source>Next Counter Value</source>
        <translation>Siguiente Contador</translation>
    </message>
    <message>
        <location filename="../qml/pages/AddOTP.qml" line="172"/>
        <source>Next Value of the Counter</source>
        <translation>Siguiente valor del contador</translation>
    </message>
</context>
<context>
    <name>ExportPage</name>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="63"/>
        <source>File already exists, choose &quot;Overwrite existing&quot; to overwrite it.</source>
        <translation>El fichero ya existe, escoja la opción &quot;Sobreescribir existente&quot; para sobreescribirlo.</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="72"/>
        <source>Given file does not exist!</source>
        <translation>¡El fichero proporcionado no exsiste!</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="91"/>
        <location filename="../qml/pages/ExportPage.qml" line="107"/>
        <source>Export</source>
        <translation>Exportar</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="91"/>
        <location filename="../qml/pages/ExportPage.qml" line="107"/>
        <source>Import</source>
        <translation>Importar</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="114"/>
        <source>Filename</source>
        <translation>Nombre del fichero</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="115"/>
        <source>File to import</source>
        <translation>Fichero a importar</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="115"/>
        <source>File to export</source>
        <translation>Fichero a exportar</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="128"/>
        <source>Overwrite existing</source>
        <translation>Sobreescribir existente</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="134"/>
        <source>Password</source>
        <translation>Contraseña</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="135"/>
        <source>Password for the file</source>
        <translation>Contraseña para el fichero</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="148"/>
        <source>Passwords don&apos;t match!</source>
        <translation>¡Las contraseñas no coinciden!</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="148"/>
        <source>Passwords match!</source>
        <translation>¡Las contraseñas coinciden!</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="149"/>
        <source>Repeated Password for the file</source>
        <translation>Contraseña repetida para el archivo</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="173"/>
        <source>Here you can Import Tokens from a file. Put in the file location and the password you used on export. Pull left to start the import.</source>
        <translation>Aquí puede Importar Tokens desde un fichero. Ponga la localización del fichero y la contraseña utilizada en la exportación. Tire hacia la izquierda para comenzar la importación.</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="189"/>
        <source>Here you can export Tokens to a file. The exported file will be encrypted with AES-256-CBC and Base64 encoded. Choose a strong password, the file will contain the secrets used to generate the Tokens for your accounts. Pull left to start the export.</source>
        <translation>Aquí puede exportar Tokens a un fichero. El fichero exportado será encriptado con AES-256-CBC y codificado en Base64. Escoja una contraseña segura, el fichero contendrá las cadenas secretas utilizadas para la generación de los Tokens. Tire hacia la izquierda para comenzar la exportación.</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="189"/>
        <source>To view the content of the export file outside of SailOTP use the following openssl command:</source>
        <translation>Para ver los contenidos del fichero de exportación fuera de SailOTP utilize el siguiente comando openssl:</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="211"/>
        <source>Error writing to file </source>
        <translation>Error escribiendo el fichero</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="213"/>
        <source>Token Database exported to </source>
        <translation>Base de datos de Tokens exportada en</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="216"/>
        <source>Could not encrypt tokens. Error: </source>
        <translation>No se ha podido encriptar los tokens. Error: </translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="219"/>
        <source>Could not read tokens from Database</source>
        <translation>No se ha podido leer los tokens desde la Base de datos</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="230"/>
        <source>Tokens imported from </source>
        <translation>Tokens importados desde</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="235"/>
        <source>Unable to decrypt file, did you use the right password?</source>
        <translation>No se ha podido desencriptar el fichero, ¿ha utilizado el password correcto?</translation>
    </message>
    <message>
        <location filename="../qml/pages/ExportPage.qml" line="238"/>
        <source>Could not read from file </source>
        <translation>No se ha podido leer desde el fichero</translation>
    </message>
</context>
<context>
    <name>MainView</name>
    <message>
        <location filename="../qml/pages/MainView.qml" line="109"/>
        <source>About</source>
        <translation>Acerca de</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="113"/>
        <source>Settings</source>
        <translation>Configuración</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="118"/>
        <source>Export / Import</source>
        <translation>Exportar/Importar</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="122"/>
        <source>Add Token</source>
        <translation>Añadir Token</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="136"/>
        <source>Nothing here</source>
        <translation>Nada aquí</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="137"/>
        <source>Pull down to add a OTP</source>
        <translation>Tire hacia abajo para añadir tokens OTP</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="178"/>
        <source>Search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="198"/>
        <source>Deleting</source>
        <translation>Borrando</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="219"/>
        <location filename="../qml/pages/MainView.qml" line="293"/>
        <source>Token for </source>
        <translation>Token para </translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="219"/>
        <location filename="../qml/pages/MainView.qml" line="293"/>
        <source> copied to clipboard</source>
        <translation> copiado al portapapeles</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="289"/>
        <source>Copy to Clipboard</source>
        <translation>Copiar al portapapeles</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="297"/>
        <source>Show Token as QR-Code</source>
        <translation>Mostrar código QR</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="302"/>
        <source>Move up</source>
        <translation>Ascender</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="307"/>
        <source>Move down</source>
        <translation>Descender</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="312"/>
        <source>Edit</source>
        <translation>Editar</translation>
    </message>
    <message>
        <location filename="../qml/pages/MainView.qml" line="318"/>
        <source>Delete</source>
        <translation>Borrar</translation>
    </message>
</context>
<context>
    <name>QRPage</name>
    <message>
        <location filename="../qml/pages/QRPage.qml" line="74"/>
        <source>Can&apos;t create QR-Code from an empty String</source>
        <translatorcomment>Google Translate</translatorcomment>
        <translation>No se puede crear un código QR desde una cadena vacía</translation>
    </message>
</context>
<context>
    <name>ScanOTP</name>
    <message>
        <location filename="../qml/pages/ScanOTP.qml" line="54"/>
        <source>Can&apos;t access temporary directory</source>
        <translation>No se puede acceder al directorio temporal</translation>
    </message>
    <message>
        <location filename="../qml/pages/ScanOTP.qml" line="64"/>
        <source>Add manually</source>
        <translation>Añadir manualmente</translation>
    </message>
    <message>
        <location filename="../qml/pages/ScanOTP.qml" line="71"/>
        <source>Scan Code</source>
        <translation>Escanear código</translation>
    </message>
    <message>
        <location filename="../qml/pages/ScanOTP.qml" line="71"/>
        <source>Scanning...</source>
        <translation>Escaneando...</translation>
    </message>
    <message>
        <location filename="../qml/pages/ScanOTP.qml" line="96"/>
        <source>No valid Token data found.</source>
        <translation>No se han encontrado datos válidos</translation>
    </message>
    <message>
        <location filename="../qml/pages/ScanOTP.qml" line="137"/>
        <source>Tap the picture to start / stop scanning. Pull down to add Token manually.</source>
        <translation>Toque la imagen para comenzar/parar el escaneo. Tire hacia abajo para una configuración manual.</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <location filename="../qml/pages/Settings.qml" line="50"/>
        <source>Settings</source>
        <translation>Configuración</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="52"/>
        <source>Behaviour</source>
        <translation>Comportamiento</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="56"/>
        <source>Show Token as QR on Tap</source>
        <translatorcomment>Google Translate</translatorcomment>
        <translation>Mostrar token como QR en el tap</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="68"/>
        <source>Hide Tokens and Reveal on Tap</source>
        <translatorcomment>Google Translate</translatorcomment>
        <translation>Ocultar tokens y revelar en tap</translation>
    </message>
</context>
</TS>
